Instructions
============

.. currentmodule:: compas_rrc

Basics
------

.. autosummary::
    :toctree: generated/
    :nosignatures:

    SetAcceleration
    SetMaxSpeed
    SetTool
    SetWorkObject

Motion
------

.. autosummary::
    :toctree: generated/
    :nosignatures:

    MoveToJoints
    MoveToFrame
    MoveToRobtarget
    Motion
    Zone

Position
--------

.. autosummary::
    :toctree: generated/
    :nosignatures:

    GetFrame
    GetJoints
    GetRobtarget

Input/Output
------------

.. autosummary::
    :toctree: generated/
    :nosignatures:

    ReadAnalog
    ReadDigital
    ReadGroup
    SetAnalog
    SetDigital
    SetGroup
    PulseDigital

Utility
-------

.. autosummary::
    :toctree: generated/
    :nosignatures:

    Noop
    PrintText
    Stop
    WaitTime

Watch
-----

.. autosummary::
    :toctree: generated/
    :nosignatures:

    ReadWatch
    StartWatch
    StopWatch
